@@ -2,7 +2,7 @@ package CatalystX::AppBuilder;
 use Moose;
 use namespace::clean -except => qw(meta);
 
-our $VERSION = '0.00009';
+our $VERSION = '0.00010';
 
 has appname => (
     is => 'ro',
@@ -167,12 +167,14 @@ sub inherited_path_to {
         $m .= '.pm';
         my $f = Path::Class::File->new($INC{$m})->parent;
         while ($f) {
-           if (-f $f->file('Makefile.PL') ) {
-               $f = $f->subdir(@paths)->stringify;
-               last;
-           }
-           last if $f->stringify eq $f->parent->stringify;
-           $f = $f->parent;
+            for my $stopper (qw(Makefile.PL Build.PL dist.ini minil.toml)) {
+                if (-f $f->file($stopper)) {
+                    $f = $f->subdir(@paths)->stringify;
+                    last;
+                }
+            }
+            last if $f->stringify eq $f->parent->stringify;
+            $f = $f->parent;
         }
         $f;
     } @inheritance;
